import 'package:isa/isa.dart';
import 'package:measures/measures.dart';
import 'package:test/test.dart';

typedef ISA = InternationalStandardAtmosphere;

void main() {
  final isa = ISA();
  test('Standard Atmosphere at Sea Level', () {
    final geometricAlt = Altitude.fromMetres(0.0);
    expect(isa.getGeopotentialAt(geometricAlt).m, 0.0);
    expect(isa.getTemperatureAt(geometricAlt).kelvin, 288.15);
    expect(isa.getTemperatureAt(geometricAlt).celsius, 15.0);
    expect(isa.getPressureAt(geometricAlt).hPa, 1013.25);
    expect(isa.getDensityAt(geometricAlt).kgMCub, 1.2250000181242879);
    expect(isa.getGravityAccelAt(geometricAlt).msSq, 9.80665);
    expect(isa.getSoundSpdAt(geometricAlt).ms, 340.29399304979984);
  });
  test('Standard Atmosphere at 3000 m', () {
    final geometricAlt = Altitude.fromMetres(3000.0);
    expect(isa.getGeopotentialAt(geometricAlt).m.roundToDouble(), 2999);
    expect(isa.getTemperatureAt(geometricAlt).kelvin, 268.65919845164115);
    expect(isa.getTemperatureAt(geometricAlt).celsius, -4.490801548358853);
    expect(isa.getPressureAt(geometricAlt).hPa, 701.2114406807561);
    expect(isa.getDensityAt(geometricAlt).kgMCub, 0.9092543452517026);
    expect(isa.getGravityAccelAt(geometricAlt).msSq, 9.797400285127708);
    expect(isa.getSoundSpdAt(geometricAlt).ms,
        328.5835582347773); //328.5835582351748
  });
  test('Standard Atmosphere at 10000 m', () {
    final geometricAlt = Altitude.fromMetres(10000.0);
    expect(isa.getGeopotentialAt(geometricAlt).m.roundToDouble(), 9984);
    expect(isa.getTemperatureAt(geometricAlt).kelvin, 223.25209264797857);
    expect(isa.getTemperatureAt(geometricAlt).celsius, -49.897907352021406);
    expect(isa.getPressureAt(geometricAlt).hPa, 264.9987312280235);
    expect(isa.getDensityAt(geometricAlt).kgMCub, 0.41351032959256634);
    expect(isa.getGravityAccelAt(geometricAlt).msSq, 9.775868442887434);
    expect(isa.getSoundSpdAt(geometricAlt).ms, 299.53166468401133);
  });
  test('Standard Atmosphere at 50000 m', () {
    final geometricAlt = Altitude.fromMetres(80000.0);
    expect(isa.getGeopotentialAt(geometricAlt).m.roundToDouble(), 79006);
    expect(isa.getTemperatureAt(geometricAlt).kelvin, 198.63857625086882);
    expect(isa.getTemperatureAt(geometricAlt).celsius, -74.51142374913115);
    expect(isa.getPressureAt(geometricAlt).hPa, 0.010524650444324315);
    expect(isa.getDensityAt(geometricAlt).kgMCub, 0.000018457895946854782);
    expect(isa.getGravityAccelAt(geometricAlt).msSq, 9.56439894343608);
    expect(isa.getSoundSpdAt(geometricAlt).ms, 282.5379357267004);
  });
}
